==> kyamo_0.13.99+0.2a.orig.tar.gz: kyamo-0.2a/src/cleanup.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Roland Weigert   *
 *   roweigert@t-online.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

using  namespace std;

#ifndef _CLEANUP_H
#define _CLEANUP_H

#include <iostream>

#include <qdir.h>
#include <qstring.h>
#include <qstringlist.h>
#include <qfileinfo.h>
#include <qmessagebox.h>
#include <qdir.h>
#include <klocale.h>

#include "taglibschnittstelle.h"
#include "id3tag.h"
#include "rcdatei.h"
#include "progress.h"
#include "filter.h"

class cleanup : public QObject
  {
    Q_OBJECT
  public:
    QUrlOperator *url;
    QWidget *parent;
    long goodfiles;
    long badfiles;
    bool abort;
    bool directoriesok;
    bool filterok;
    progressmainwindow *progresswindow;
    filter *cleanupfilter;
    QString path;
    cleanup(QWidget *);
    ~cleanup()
    {}
    void cleanupdir(QStringList *,long);
    void cleanupcd(QStringList *,long);
    void checkdirempty(QString);
  private:
    bool notcopied;
  public slots:
    void abortslot();
    void copyfinished();
  };

#endif //_CLEANUP_H_

==> kyamo_0.40+0.4a.orig.tar.gz: kyamo-0.40a4-2/src/cleanup.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Roland Weigert   *
 *   roweigert@t-online.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

using  namespace std;

#ifndef _CLEANUP_H
#define _CLEANUP_H

#include <iostream>

#include <qdir.h>
#include <qstring.h>
#include <qstringlist.h>
#include <qfileinfo.h>
#include <qfile.h>
#include <qdatastream.h>
#include <qmessagebox.h>
#include <qdir.h>
#include <qimage.h>
#include <klocale.h>

#include "rcdatei.h"
#include "progress.h"
#include "filter.h"
#include "tagenginewrapper.h"
#include "databasewrapper.h"
#include "fileoperations.h"

class cleanup : public QObject
  {
    Q_OBJECT
  public:
    QUrlOperator *url;
    QWidget *parent;
    long goodfiles;
    long badfiles;
    bool abort;
    bool directoriesok;
    bool filterok;
    progressmainwindow *progresswindow;
    filter *cleanupfilter;
    QString path;
    cleanup(QWidget *);
    ~cleanup();
    void cleanupdir(QStringList *,long);
    void cleanupcd(QStringList *,long);
    void checkdirempty(QString);
  public slots:
    void abortslot();
  };

#endif //_CLEANUP_H_
